
#ifndef KONTACTINTERFACE_EXPORT_H
#define KONTACTINTERFACE_EXPORT_H

#ifdef KONTACTINTERFACE_STATIC_DEFINE
#  define KONTACTINTERFACE_EXPORT
#  define KONTACTINTERFACE_NO_EXPORT
#else
#  ifndef KONTACTINTERFACE_EXPORT
#    ifdef kontactinterface_EXPORTS
        /* We are building this library */
#      define KONTACTINTERFACE_EXPORT __declspec(dllexport)
#    else
        /* We are using this library */
#      define KONTACTINTERFACE_EXPORT __declspec(dllimport)
#    endif
#  endif

#  ifndef KONTACTINTERFACE_NO_EXPORT
#    define KONTACTINTERFACE_NO_EXPORT 
#  endif
#endif

#ifndef KONTACTINTERFACE_DEPRECATED
#  define KONTACTINTERFACE_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef KONTACTINTERFACE_DEPRECATED_EXPORT
#  define KONTACTINTERFACE_DEPRECATED_EXPORT KONTACTINTERFACE_EXPORT KONTACTINTERFACE_DEPRECATED
#endif

#ifndef KONTACTINTERFACE_DEPRECATED_NO_EXPORT
#  define KONTACTINTERFACE_DEPRECATED_NO_EXPORT KONTACTINTERFACE_NO_EXPORT KONTACTINTERFACE_DEPRECATED
#endif

#define DEFINE_NO_DEPRECATED 0
#if DEFINE_NO_DEPRECATED
# define KONTACTINTERFACE_NO_DEPRECATED
#endif

#endif
